clr_loc: Location colors

Description Usage Format Details

Description

clr_loc defines the colors for sample locations within plots.

Usage

1

Format

An object of class character of length 4.

Details

This is used in color scales thoughout the paper where the locations are indicated by color.


k-hench/GenomicOriginsScripts documentation built on July 24, 2021, 3:05 p.m.