Description Usage Arguments Details See Also
custom_annoplot extracts and plots hypoplectrus annotation data
1 2 3 4 5 6 7 8 9 10 11 12 |
... |
catch-all parameter to allow excessive parameters through purrr::pmap |
searchLG |
string, linkage group (eg. "LG08") |
xrange |
numeric vector of length 2, range of the plotted window |
genes_of_interest |
vector of strings, genes that receive a label |
genes_of_sec_interest |
vector of strings (deprecate/legacy) |
anno_rown |
numeric, number of rows used for gene annotation |
width |
numeric, width of genes |
gene_color |
string (color), highlight color for genes |
start |
numeric, start position of window (bp) |
end |
numeric, end position of window (bp) |
This is a modification of hypogen::hypo_annotation_baseplot(). The highlighting of the outlier area is added and the coloration of genes is simplified to ony a single color.
Other Figure 5:
ax_scl(),
cross_spec(),
dist_tibble(),
distances_tree(),
get_clr(),
get_dist(),
get_gxp_long(),
get_isolated_topos(),
get_neighbour_topos(),
is_isolated(),
min_dist(),
no_title(),
plot_curtain(),
plot_fish_zoom(),
plot_fst_poptree(),
plot_leg(),
plot_panel_anno(),
plot_panel_delta_dxy(),
plot_panel_dxy(),
plot_panel_fst(),
plot_panel_gxp(),
plot_panel_twisst(),
prep_data(),
theme_panels()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.