get_cc: Import cross coalescence data

Description Usage Arguments Details See Also

View source: R/functions_f2.R

Description

get_msmc imports cross coalescence data and extracts according run information.

Usage

1
get_cc(file, cc_groups, cc_path, mu = 3.7e-08, gen = 1)

Arguments

file

cross coalescence file

cc_groups

cross coalescence group assignment reference table

cc_path

cross coalescence results path

mu

mutation rate mu

gen

generation time in years

Details

The data is imported and run components are extracted from the a reference table, and added to the data.

See Also

Other Figure 2: get_msmc()


k-hench/GenomicOriginsScripts documentation built on July 24, 2021, 3:05 p.m.