get_gxp: Import genotype x phenotype association

Description Usage Arguments Details See Also

View source: R/functions_general.R

Description

get_gxp imports genotype x phenotype association data and adds the genomic position.

Usage

1

Arguments

file

input file

Details

The phenotype trait name is extracted from the file name and converted into a label for plotting. Then, the data is imported and reduced to the columns containg the genomic poistion and the p values of the wald test. The column containing the p values is renamed according to the trait.

See Also

Other General functions: darken(), export_2_latex(), get_dxy(), get_fst_summary_data(), get_fst(), get_pi(), join_list(), lighten(), process_input(), refactor()


k-hench/GenomicOriginsScripts documentation built on July 24, 2021, 3:05 p.m.