Description Usage Arguments Details See Also
get_gxp_long imports genotype x phenotype association data in long format.
1 | get_gxp_long(file, kb = 10)
|
file |
gpx results file |
kb |
gxp window size (matching file for string manipulation) |
The phenotype trait name is extracted from the file name. Then, the data is imported, the genomic poistion and the trait name is added as columns.
Other Figure 5:
ax_scl(),
cross_spec(),
custom_annoplot(),
dist_tibble(),
distances_tree(),
get_clr(),
get_dist(),
get_isolated_topos(),
get_neighbour_topos(),
is_isolated(),
min_dist(),
no_title(),
plot_curtain(),
plot_fish_zoom(),
plot_fst_poptree(),
plot_leg(),
plot_panel_anno(),
plot_panel_delta_dxy(),
plot_panel_dxy(),
plot_panel_fst(),
plot_panel_gxp(),
plot_panel_twisst(),
prep_data(),
theme_panels()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.