Description Usage Arguments Details See Also
is_isolated finds all topologies where a species is isolated
1 | get_isolated_topos(topo_plots, left_neighbour, pops)
|
topo_plots |
tibble containing the topologies (in column 'phylo') |
left_neighbour |
string (species identifier for left neighbor) |
pops |
all populations within the topology |
First the distance matrixes of all topologies are created and attached to the topologies. Then, the isolation status of a species is determined based on the distance matrixes and the topologies are filtered for the isolation cases.
The index number of those topologies is exported.
Other Figure 5:
ax_scl(),
cross_spec(),
custom_annoplot(),
dist_tibble(),
distances_tree(),
get_clr(),
get_dist(),
get_gxp_long(),
get_neighbour_topos(),
is_isolated(),
min_dist(),
no_title(),
plot_curtain(),
plot_fish_zoom(),
plot_fst_poptree(),
plot_leg(),
plot_panel_anno(),
plot_panel_delta_dxy(),
plot_panel_dxy(),
plot_panel_fst(),
plot_panel_gxp(),
plot_panel_twisst(),
prep_data(),
theme_panels()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.