Description Usage Arguments Details See Also
View source: R/functions_f5_cross_topo.R
get_neighbour_topos finds all topologies where two species are sister species
1 | get_neighbour_topos(topo_plots, left_neighbour, right_neighbour)
|
topo_plots |
tibble containing the topologies (in column 'phylo') |
left_neighbour |
string (species identifier for left neighbor) |
right_neighbour |
string (species identifier for right neighbor) |
First the distances of all species within all topologies are created. This is subset for the topologies where the distance between the two species equals 2 (2 edges).
Other Figure 5:
ax_scl(),
cross_spec(),
custom_annoplot(),
dist_tibble(),
distances_tree(),
get_clr(),
get_dist(),
get_gxp_long(),
get_isolated_topos(),
is_isolated(),
min_dist(),
no_title(),
plot_curtain(),
plot_fish_zoom(),
plot_fst_poptree(),
plot_leg(),
plot_panel_anno(),
plot_panel_delta_dxy(),
plot_panel_dxy(),
plot_panel_fst(),
plot_panel_gxp(),
plot_panel_twisst(),
prep_data(),
theme_panels()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.