Description Usage Arguments Details See Also
View source: R/functions_general.R
get_pi imports diversity data and adds the genomic position.
1 |
file |
input file |
The data is imported and genomic position and species name are added.
Other General functions:
darken(),
export_2_latex(),
get_dxy(),
get_fst_summary_data(),
get_fst(),
get_gxp(),
join_list(),
lighten(),
process_input(),
refactor()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.