Description Usage Arguments Details See Also
no_title provides further styling for panels of Figure 3
1 |
... |
parameters to funnel through to ggplot2::theme() |
This function removes the y axis title and grid elements of second and third column panels in Figure 3.
Other Figure 5:
ax_scl(),
cross_spec(),
custom_annoplot(),
dist_tibble(),
distances_tree(),
get_clr(),
get_dist(),
get_gxp_long(),
get_isolated_topos(),
get_neighbour_topos(),
is_isolated(),
min_dist(),
plot_curtain(),
plot_fish_zoom(),
plot_fst_poptree(),
plot_leg(),
plot_panel_anno(),
plot_panel_delta_dxy(),
plot_panel_dxy(),
plot_panel_fst(),
plot_panel_gxp(),
plot_panel_twisst(),
prep_data(),
theme_panels()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.