Description Usage Format Details
outlr_clr defines the color used to highlight Fst outlier windows in plots.
1 |
An object of class character of length 1.
This defines the color used to highlight Fst outlier windows in plots.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.