Description Usage Arguments Details See Also
plot_fish_zoom creates a hamlet annotation from a predefined table.
1 | plot_fish_zoom(anno_tab, idx, height = 0.1, width = 5)
|
anno_tab |
tibble with annotation layout for the twisst legend |
idx |
legend element index |
height |
legend element height |
width |
legend element width |
This funtion is used in the creation of the topology legend.
Other Figure 5:
ax_scl(),
cross_spec(),
custom_annoplot(),
dist_tibble(),
distances_tree(),
get_clr(),
get_dist(),
get_gxp_long(),
get_isolated_topos(),
get_neighbour_topos(),
is_isolated(),
min_dist(),
no_title(),
plot_curtain(),
plot_fst_poptree(),
plot_leg(),
plot_panel_anno(),
plot_panel_delta_dxy(),
plot_panel_dxy(),
plot_panel_fst(),
plot_panel_gxp(),
plot_panel_twisst(),
prep_data(),
theme_panels()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.