Description Usage Arguments Details See Also
plot_leg creates the elements of the topology highlighting legend.
1 2 3 4 5 6 7 |
spec1 |
string, three letter species identifier |
spec2 |
string, three letter species identifier |
color |
string, color |
size |
numeric, line width |
mode |
string, legend element mode ("pair"/"isolation") |
This funtion is used to create the topologie legend of a single a single highlighing scheme. Depending on the highlighting mode (pair/ isolation), the background geometry is created and the hamlet annotations are collected.
Then the geometry is plotted an the hamlets are added.
Other Figure 5:
ax_scl(),
cross_spec(),
custom_annoplot(),
dist_tibble(),
distances_tree(),
get_clr(),
get_dist(),
get_gxp_long(),
get_isolated_topos(),
get_neighbour_topos(),
is_isolated(),
min_dist(),
no_title(),
plot_curtain(),
plot_fish_zoom(),
plot_fst_poptree(),
plot_panel_anno(),
plot_panel_delta_dxy(),
plot_panel_dxy(),
plot_panel_fst(),
plot_panel_gxp(),
plot_panel_twisst(),
prep_data(),
theme_panels()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.