Description Usage Arguments Details See Also
plot_network creates a ggplot with a network of species comparisons.
1 | plot_network(loc, nodes, edges, asp = 0.8, sep = 0, node_lab_shift = 0)
|
loc |
location (Belize/ Honduras/ Panama) |
nodes |
tibble containing network nodes |
edges |
tibble containing network edges |
asp |
plot aspect ration |
sep |
buffer network segments from nodes |
node_lab_shift |
relative label position on edge |
This creates a network for all pairwise species comparisons within a location.
Other Figure 1:
make_faint_clr(),
network_layout(),
plot_fish(),
summarize_dxy(),
summarize_fst(),
whisker_points()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.