Description Usage Arguments Details See Also
plot_panel_anno plots the gene models of a selected outlier window
1 | plot_panel_anno(outlier_id, label, lg, start, end, genes = c(), ...)
|
outlier_id |
string, identifier of fst outlier ID (eg "LG04_1") |
label |
string, panel label ("A"/"B"/"C") |
lg |
string, linkage group (eg. "LG08") |
start |
numeric, start position of window (bp) |
end |
numeric, end position of window (bp) |
genes |
vector of strings, genes that receive a label |
... |
catch-all parameter to allow excessive parameters through purrr::pmap |
The overal column title is created and the annotation data is plotted.
Other Figure 5:
ax_scl(),
cross_spec(),
custom_annoplot(),
dist_tibble(),
distances_tree(),
get_clr(),
get_dist(),
get_gxp_long(),
get_isolated_topos(),
get_neighbour_topos(),
is_isolated(),
min_dist(),
no_title(),
plot_curtain(),
plot_fish_zoom(),
plot_fst_poptree(),
plot_leg(),
plot_panel_delta_dxy(),
plot_panel_dxy(),
plot_panel_fst(),
plot_panel_gxp(),
plot_panel_twisst(),
prep_data(),
theme_panels()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.