Description Usage Arguments Details See Also
plot_panel_delta_dxy plots the dxy panel of a selected outlier window
1 | plot_panel_delta_dxy(lg, start, end, ...)
|
lg |
string, linkage group (eg. "LG08") |
start |
numeric, start position of window (bp) |
end |
numeric, end position of window (bp) |
... |
catch-all parameter to allow excessive parameters through purrr::pmap |
The delta dxy data is subsetted to mathch the outlier area, then the panel is plotted.
Other Figure 5:
ax_scl(),
cross_spec(),
custom_annoplot(),
dist_tibble(),
distances_tree(),
get_clr(),
get_dist(),
get_gxp_long(),
get_isolated_topos(),
get_neighbour_topos(),
is_isolated(),
min_dist(),
no_title(),
plot_curtain(),
plot_fish_zoom(),
plot_fst_poptree(),
plot_leg(),
plot_panel_anno(),
plot_panel_dxy(),
plot_panel_fst(),
plot_panel_gxp(),
plot_panel_twisst(),
prep_data(),
theme_panels()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.