plot_size: Default plot size

Description Usage Format Details

Description

plot_size sets the default size of data points in plots.

Usage

1

Format

An object of class numeric of length 1.

Details

This sets the default size of data points thoughout the figures.


k-hench/GenomicOriginsScripts documentation built on July 24, 2021, 3:05 p.m.