plot_text_size: Default plot font size

Description Usage Format Details

Description

plot_text_size sets the default font size of text in plots.

Usage

1

Format

An object of class numeric of length 1.

Details

This sets the default font size of text thoughout the figures.


k-hench/GenomicOriginsScripts documentation built on July 24, 2021, 3:05 p.m.