Description Usage Format Details
clr_loc defines the colors for sample locations within plots.
1 |
An object of class character of length 4.
This is used in color scales thoughout the paper where the locations are indicated by color.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.