Description Usage Arguments Details See Also
get_msmc imports cross coalescence data and extracts according run information.
1 |
file |
cross coalescence file |
cc_groups |
cross coalescence group assignment reference table |
cc_path |
cross coalescence results path |
mu |
mutation rate mu |
gen |
generation time in years |
The data is imported and run components are extracted from the a reference table, and added to the data.
Other Figure 2:
get_msmc()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.