Description Usage Arguments Details See Also
View source: R/functions_general.R
get_gxp imports genotype x phenotype association data and adds the genomic position.
1 |
file |
input file |
The phenotype trait name is extracted from the file name and converted into a label for plotting. Then, the data is imported and reduced to the columns containg the genomic poistion and the p values of the wald test. The column containing the p values is renamed according to the trait.
Other General functions:
darken(),
export_2_latex(),
get_dxy(),
get_fst_summary_data(),
get_fst(),
get_pi(),
join_list(),
lighten(),
process_input(),
refactor()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.