Description Usage Arguments Details See Also
View source: R/functions_f5_plotting.R
plot_curtain calls all individual plotting functions needed for a single outlier zoom
1 2 3 4 5 6 7 8 9 10 11 12 13 14 |
loc |
string, sample location (bel [Belize]/ hon [Honduras]/ pan [Panama]) |
outlier_id |
string, identifier of fst outlier ID (eg "LG04_1") |
outlier_nr |
numeric (deprecated) |
lg |
string, linkage group (eg. "LG08") |
start |
numeric, start position of window (bp) |
end |
numeric, end position of window (bp) |
cool_genes |
vector of strings, genes that receive a label |
text |
logical, toggle y axis label and ticks |
label |
string, panel label ("A"/"B"/"C") |
trait |
string, trait identifier for icon on gxp plot |
data_tables |
list with twisst results |
... |
catch-all parameter to allow excessive parameters through purrr::pmap |
The panels containg the gene models, fst, dxy delta dxy, genotype x phenotype association and topology weighting are called.
Then they are combined using cowplot::plot_grid and
depending on the column position (first column/ other column),
the y axis titles are removed.
Other Figure 5:
ax_scl(),
cross_spec(),
custom_annoplot(),
dist_tibble(),
distances_tree(),
get_clr(),
get_dist(),
get_gxp_long(),
get_isolated_topos(),
get_neighbour_topos(),
is_isolated(),
min_dist(),
no_title(),
plot_fish_zoom(),
plot_fst_poptree(),
plot_leg(),
plot_panel_anno(),
plot_panel_delta_dxy(),
plot_panel_dxy(),
plot_panel_fst(),
plot_panel_gxp(),
plot_panel_twisst(),
prep_data(),
theme_panels()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.