Description Usage Format Details
plot_size sets the default size of data points in plots.
1 |
An object of class numeric of length 1.
This sets the default size of data points thoughout the figures.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.