Description Usage Format Details
plot_text_size sets the default font size of text in plots.
1 |
An object of class numeric of length 1.
This sets the default font size of text thoughout the figures.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.